/*
 * Java comm library component.
 *
 * Copyright (c) 1998
 *      Transvirtual Technologies, Inc.  All rights reserved.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file.
 */

package javax.comm;

import java.util.EventListener;

public interface ParallelPortEventListener
  extends EventListener {

    void parallelEvent(ParallelPortEvent ev);

}
